@@ -1,5 +1,5 @@
 package Games::ABC_Path::Solver;
-$Games::ABC_Path::Solver::VERSION = '0.6.2';
+$Games::ABC_Path::Solver::VERSION = '0.8.0';
 use warnings;
 use strict;
 
@@ -20,12 +20,22 @@ Games::ABC_Path::Solver - a solver for ABC Path
 
 =head1 VERSION
 
-version 0.6.2
+version 0.8.0
 
 =head1 SYNOPSIS
 
 See L<Games::ABC_Path::Solver::Board> for more information.
 
+=head1 How to play? The Rules of the Game
+
+The 5*5 grid must be filled with a contiguous path of the first 25 (= 5 * 5)
+letters of the Latin alphabet (“A” to “Y”), in order. Moves in the path can be
+diagonal, but they cannot wrap through the edges of the grid.
+
+The position of the letter “A” is given. In addition, for every horizontal
+row, vertical column, and the two diagonals, there are two letters that should
+appear in them (but in any order, and with possible gaps).
+
 =head1 AUTHOR
 
 Shlomi Fish, C<< <shlomif at cpan.org> >>
@@ -122,7 +132,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Shlomi Fish.
+This software is Copyright (c) 2024 by Shlomi Fish.
 
 This is free software, licensed under:
 
