@@ -1,9 +1,9 @@
 package Games::ABC_Path::Solver::Board;
-$Games::ABC_Path::Solver::Board::VERSION = '0.6.2';
+$Games::ABC_Path::Solver::Board::VERSION = '0.8.0';
 use warnings;
 use strict;
-
-use 5.008;
+use 5.014;
+use autodie;
 
 
 use Carp;
@@ -942,7 +942,7 @@ Games::ABC_Path::Solver::Board - handles an ABC Path board.
 
 =head1 VERSION
 
-version 0.6.2
+version 0.8.0
 
 =head1 SYNOPSIS
 
@@ -966,6 +966,16 @@ version 0.6.2
         print +(' => ' x $move->get_depth()), $move->get_text(), "\n";
     }
 
+=head1 How to play? The Rules of the Game
+
+The 5*5 grid must be filled with a contiguous path of the first 25 (= 5 * 5)
+letters of the Latin alphabet (“A” to “Y”), in order. Moves in the path can be
+diagonal, but they cannot wrap through the edges of the grid.
+
+The position of the letter “A” is given. In addition, for every horizontal
+row, vertical column, and the two diagonals, there are two letters that should
+appear in them (but in any order, and with possible gaps).
+
 =head1 FUNCTIONS
 
 =head2 new
@@ -1115,7 +1125,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Shlomi Fish.
+This software is Copyright (c) 2024 by Shlomi Fish.
 
 This is free software, licensed under:
 
